### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### [1.1.0](https://github.com/hemna/aprsd-webchat-extension/compare/1.0.0...1.1.0)

> 19 September 2025

- Added activity to README [`069c911`](https://github.com/hemna/aprsd-webchat-extension/commit/069c9114a819ec8b23ce6ad1a8690fd68f78eb98)
- Update for 4.2.0 release [`9ac0f7a`](https://github.com/hemna/aprsd-webchat-extension/commit/9ac0f7a89359ad0ce618eb15f3421a6f80902b0f)

### [1.0.0](https://github.com/hemna/aprsd-webchat-extension/compare/v0.1.0...1.0.0)

> 6 January 2025

- Initial commit. [`d1ec549`](https://github.com/hemna/aprsd-webchat-extension/commit/d1ec5493e016ba72f1aba42b39ea83ef9760f045)
- More updates [`c28d677`](https://github.com/hemna/aprsd-webchat-extension/commit/c28d6772ae10ab880635f81e38c520f9c64e7e74)
- Get content to work again [`f5ce4a6`](https://github.com/hemna/aprsd-webchat-extension/commit/f5ce4a6646f894877c86ef00ac56377de868ec90)
- Added Changelog makefile [`591d6a1`](https://github.com/hemna/aprsd-webchat-extension/commit/591d6a1712cca9f3adaa0a3775ff0b3dde99fb82)
- Updated Changelog [`a6dccce`](https://github.com/hemna/aprsd-webchat-extension/commit/a6dcccec4faed1cd4e911f8246aa263692d4ac2c)
- Needs aprsd 3.5.0 &gt; [`70a346c`](https://github.com/hemna/aprsd-webchat-extension/commit/70a346c0131d7e39b5da36e5ab034e1f17ef9d14)
- small optimization [`91aa556`](https://github.com/hemna/aprsd-webchat-extension/commit/91aa556203e87e087b3537df401bb21401b0960c)
- Update clean [`6390ae9`](https://github.com/hemna/aprsd-webchat-extension/commit/6390ae98f98c83015ca90fb3a51bbe27a55b32ad)
- Updated README with how to run [`a94bc75`](https://github.com/hemna/aprsd-webchat-extension/commit/a94bc75cdcef8a1966929121ac471bf9d061eea1)
- Updated access to keepalive [`2b92507`](https://github.com/hemna/aprsd-webchat-extension/commit/2b92507c47201f7f9a8972ccec6d2f420aee8a89)
- Use ruff [`610ff07`](https://github.com/hemna/aprsd-webchat-extension/commit/610ff07a38b6e9020036c1f45dfa1eba9298d497)
- ruff formatted [`7f03f2d`](https://github.com/hemna/aprsd-webchat-extension/commit/7f03f2d19228d1e5028e8ce357c996d971fb889f)
- added screenshot [`b9d2134`](https://github.com/hemna/aprsd-webchat-extension/commit/b9d21342da41c3c5c2da2a112aea9dbd45e201c5)
- updated pre-commit hook config [`a847d0d`](https://github.com/hemna/aprsd-webchat-extension/commit/a847d0d1e79c437003daf4304316b7c04857b710)
- Updated version and badges [`f944b48`](https://github.com/hemna/aprsd-webchat-extension/commit/f944b48990aba95e59e5dbde00cbb11c1026185d)

#### v0.1.0

> 9 December 2024

- Initial commit [`ced0b12`](https://github.com/hemna/aprsd-webchat-extension/commit/ced0b12fb81e875646bd6554696763491ae0cd58)
